package com.kexun.utils;

import org.apache.commons.lang.StringUtils;

/**
 * Description:
 *
 * @author lgs
 * @date 2023/05/26
 */
public class PageUtils {

    /**
     * 分页查询最大页码数
     */
    public static final Long MAX_PAGE_SIZE = 500L;

    /**
     * 获取页码
     *
     * @param no 实际页面，默认为1
     * @return 页码
     */
    public static Long getPageNo(String no) {
        Long pageNo = 1L;
        if (StringUtils.isNumeric(no)) {
            pageNo = Long.parseLong(no);
        }
        return pageNo;
    }

    /**
     * 获取每页记录数pageSize
     *
     * @param defaultPageSizes 实际每页记录数,默认10条
     * @return 每页记录数pageSize
     */
    public static Long getPageSize(String... defaultPageSizes) {
        Long pageSize = 10L;
        if (defaultPageSizes != null && defaultPageSizes.length == 1) {
            pageSize = Long.parseLong(defaultPageSizes[0]);
            if (pageSize > MAX_PAGE_SIZE) {
                pageSize = MAX_PAGE_SIZE;
            }
        }

        return pageSize;
    }

    /**
     * 获取每页记录数pageSize
     *
     * @param defaultPageSizes 实际每页记录数,字符串,默认10条
     * @return 每页记录数pageSize
     */
    public static Long getStringPageSize(String... defaultPageSizes) {
        Long pageSize = 10L;
        if (defaultPageSizes != null && defaultPageSizes.length == 1) {
            if (StringUtils.isNumeric(defaultPageSizes[0])) {
                pageSize = Long.parseLong(defaultPageSizes[0]);
            }
            if (pageSize > MAX_PAGE_SIZE) {
                pageSize = MAX_PAGE_SIZE;
            }
        }

        return pageSize;
    }

}
